==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/SecurityHub/DisableImportFindingsForProduct.pm <==

package Paws::SecurityHub::DisableImportFindingsForProduct;
  use Moose;
  has ProductSubscriptionArn => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'ProductSubscriptionArn', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableImportFindingsForProduct');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/productSubscriptions/{ProductSubscriptionArn+}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SecurityHub::DisableImportFindingsForProductResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SecurityHub::DisableImportFindingsForProduct - Arguments for method DisableImportFindingsForProduct on L<Paws::SecurityHub>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableImportFindingsForProduct on the
L<AWS SecurityHub|Paws::SecurityHub> service. Use the attributes of this class
as arguments to method DisableImportFindingsForProduct.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisableImportFindingsForProduct.

=head1 SYNOPSIS

    my $securityhub = Paws->service('SecurityHub');
    my $DisableImportFindingsForProductResponse =
      $securityhub->DisableImportFindingsForProduct(
      ProductSubscriptionArn => 'MyNonEmptyString',

      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/securityhub/DisableImportFindingsForProduct>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ProductSubscriptionArn => Str

The ARN of a resource that represents your subscription to a supported
product.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableImportFindingsForProduct in L<Paws::SecurityHub>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/SecurityHub/DisableImportFindingsForProduct.pm <==

package Paws::SecurityHub::DisableImportFindingsForProduct;
  use Moose;
  has ProductSubscriptionArn => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'ProductSubscriptionArn', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisableImportFindingsForProduct');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/productSubscriptions/{ProductSubscriptionArn+}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SecurityHub::DisableImportFindingsForProductResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SecurityHub::DisableImportFindingsForProduct - Arguments for method DisableImportFindingsForProduct on L<Paws::SecurityHub>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisableImportFindingsForProduct on the
L<AWS SecurityHub|Paws::SecurityHub> service. Use the attributes of this class
as arguments to method DisableImportFindingsForProduct.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisableImportFindingsForProduct.

=head1 SYNOPSIS

    my $securityhub = Paws->service('SecurityHub');
    my $DisableImportFindingsForProductResponse =
      $securityhub->DisableImportFindingsForProduct(
      ProductSubscriptionArn => 'MyNonEmptyString',

      );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/securityhub/DisableImportFindingsForProduct>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ProductSubscriptionArn => Str

The ARN of the integrated product to disable the integration for.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisableImportFindingsForProduct in L<Paws::SecurityHub>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
